<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Illuminate\Support\MessageBag;

use App\Models\ZoneManagement;
use App\Models\AreaManagement;
use App\Models\User;
use App\Models\FuelCalculation;
use App\Models\FuelRate;
use App\Models\FuelRateHistory;
use App\Models\ParcelCommission;
use App\Models\UserDetail;
use App\Models\UserCity;
use App\Models\VerifiedFuelCalculation;

//Helper
use App\Helpers\Helper;
use AHLHelper;
use Log;

use PDF;

class ZoneController extends Controller
{
    public function createZone()
    {
        $breadcrumbs = [
            'name' => 'Create Zone', 
        ];

        $staffs = User::where('status', 1)->whereHas(
            'roles', function($q){
                $q->where('name', 'supervisor');
            })
        ->where(function($query) {
             $query->whereNull('zone_id');
        })
        ->get();

        return view('admin.zone.create', compact('breadcrumbs','staffs'));
    }

    public function saveZone(Request $request)
    {
        $name = $request->name;
        $code = $request->code;
        $supervisor_id = $request->supervisor_id;

        $data = [
            'name' => $name,
            'code' => $code,
        ];

        $create_zone = ZoneManagement::create($data);

        $find_user = User::where('id', $supervisor_id)->first();
        $find_user->update(['zone_id' => $create_zone->id]);

        return redirect()->route('listZone');
    }

    public function listZone()
    {
        $breadcrumbs = [
            'name' => 'List Zone', 
        ];

        $zones = ZoneManagement::all();

        return view('admin.zone.index', compact('breadcrumbs','zones'));
    }

    public function editZone($id)
    {
        $breadcrumbs = [
            'name' => 'Edit Zone', 
        ];

        $find_data = ZoneManagement::find($id);
        $staffs = User::where('status', 1)->whereHas(
            'roles', function($q){
                $q->where('name', 'supervisor');
            })
        ->where(function($query) {
             $query->whereNull('zone_id');
        })
        ->get();

        return view('admin.zone.edit', compact('breadcrumbs','find_data','staffs'));
    }

    public function updateZone(Request $request)
    {
        $data_id = $request->data_id;
        $name = $request->name;
        $code = $request->code;
        $supervisor_id = $request->supervisor_id;

        $find_data = ZoneManagement::where('id', $data_id)->first();

        $data = [
            'name' => $name,
            'code' => $code,
        ];

        $find_data->update($data);

        $find_user = User::where('id', $supervisor_id)->first();
        if(!empty($find_user))
        {
            $find_user_zone = User::where('zone_id', $data_id)->first();
            if(!empty($find_user_zone))
            {
                $find_user_zone->update(['zone_id' => NULL]);
            }
            $find_user->update(['zone_id' => $data_id]);
        }

        return redirect()->route('listZone');
    }

    //Area Management
    public function createZoneArea()
    {
        $breadcrumbs = [
            'name' => 'Create Zone Area', 
        ];

        $zones = ZoneManagement::all();

        return view('admin.area.create', compact('breadcrumbs','zones'));
    }

    public function saveZoneArea(Request $request)
    {
        $zone_id = $request->zone_id;
        $name = $request->name;
        $code = $request->code;
        $limit = $request->limit;
        $fuel = $request->fuel;

        $data = [
            'zone_id' => $zone_id,
            'name' => $name,
            'code' => $code,
            'limit' => $limit,
            'fuel' => $fuel,
            'status' => 1,
        ];

        AreaManagement::create($data);

        return redirect()->route('listZoneArea');
    }

    public function listZoneArea()
    {
        $breadcrumbs = [
            'name' => 'List Zone Area', 
        ];

        $areas = AreaManagement::all();

        return view('admin.area.index', compact('breadcrumbs','areas'));
    }

    public function editZoneArea($id)
    {
        $breadcrumbs = [
            'name' => 'Edit Zone Area', 
        ];

        $find_data = AreaManagement::find($id);
        $zones = ZoneManagement::all();

        return view('admin.area.edit', compact('breadcrumbs','find_data','zones'));
    }

    public function updateZoneArea(Request $request)
    {
        $data_id = $request->data_id;
        $zone_id = $request->zone_id;
        $name = $request->name;
        $code = $request->code;
        $limit = $request->limit;
        $fuel = $request->fuel;

        $find_data = AreaManagement::where('id', $data_id)->first();

        $data = [
            'zone_id' => $zone_id,
            'name' => $name,
            'code' => $code,
            'limit' => $limit,
            'fuel' => $fuel,
            'status' => 1,
        ];

        $find_data->update($data);

        return redirect()->route('listZoneArea');
    }

    //assigned zone list to supervisor
    public function supervisorAssignedZone()
    {
        $breadcrumbs = [
            'name' => 'Supervisor Zone Areas List', 
        ];
        $user_zone = Auth::user()->zone_id;

        $fetch_zones = ZoneManagement::where('id', $user_zone)->first();
        // if(empty($fetch_zones))
        // {
        //     dd("No Zone Assigned Right Now!");
        // }

        // dd($fetch_zones);

        return view('admin.zone.area_list',compact('fetch_zones','breadcrumbs'));
    }

    //Fuel Management
    public function addNewFuelRate()
    {
        $breadcrumbs = [
            'name' => 'Add New Fuel Rate', 
        ];

        return view('admin.fuel.create', compact('breadcrumbs'));
    }

    public function saveNewFuelRate(Request $request)
    {
        $rate = $request->rate;
        $find_rate = FuelRate::where('id', 1)->first();
        if(!empty($find_rate))
        {
            $data = [
                'rate' => $rate,
                'changed_date' => now(),
                'change_by' => Auth::user()->id,
            ];

            $find_rate->update($data);
        }
        else
        {
            $data = [
                'rate' => $rate,
                'changed_date' => now(),
                'change_by' => Auth::user()->id,
            ];

            FuelRate::create($data);
        }

        $history_data = [
            'rate' => $rate,
            'date' => now(),
            'created_by' => Auth::user()->id,
        ];

        FuelRateHistory::create($history_data);

        return redirect()->route('listFuelRate');
    }

    public function listFuelRate()
    {
        $breadcrumbs = [
            'name' => 'Fuel Rate List', 
        ];

        $datas = FuelRateHistory::orderBy('id','DESC')->get();

        return view('admin.fuel.index', compact('breadcrumbs','datas'));
    }

    //Rider Commission Management
    public function addNewRiderCommission()
    {
        $breadcrumbs = [
            'name' => 'Add New Rider Commission', 
        ];

        return view('admin.commission.rider.create', compact('breadcrumbs'));
    }

    public function saveNewRiderCommission(Request $request)
    {
        $rate = $request->rate;
        
        $data = [
            'commission' => $rate,
            'changed_date' => now(),
            'change_by' => Auth::user()->id,
            'nature' => 'rider',
        ];

        ParcelCommission::create($data);

        $riders = User::select('id','name')->whereHas(
            'roles', function($q){
                $q->where('name', 'rider');
            })
        ->where('status',1)
        ->get();

        foreach($riders as $rider)
        {
            $staffDetailData = UserDetail::where('user_id',$rider->id)->first();
            $staffDetailData->update(['commission' => $rate]);
        }

        return redirect()->route('listRiderCommission');
    }

    public function listRiderCommission()
    {
        $breadcrumbs = [
            'name' => 'Rider Commission List', 
        ];

        $datas = ParcelCommission::where('nature', 'rider')->orderBy('id','DESC')->get();

        return view('admin.commission.rider.index', compact('breadcrumbs','datas'));
    }

    //daily fuel sheet
    public function dailyFuelSheet(Request $request)
    {
        $breadcrumbs = [
            'name' => 'System Generated Daily Fuel Sheet', 
        ];
        
        if($request->date)
        {
            $requestDate = $request->date;
        }
        else
        {
            $requestDate = \Carbon\Carbon::now();
        }

        if(Auth::user()->hasAnyRole('admin'))
        {
            $userId = Auth::user()->id;

            $staffList = User::whereHas(
                'roles', function($q){
                    $q->whereIn('id', [7]);
                }
            )
            ->with('userDetail')
            ->with([
                'totalOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->whereIn('trip_status_id', [1,2,3,4,5,6,7])->where('force_status',1);
                },
                'deliveredOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',1)->where('force_status',1);
                },
                'cancelOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'returnOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'riderFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate);
                },
                'verifyFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('date', $requestDate);
                }
            ])
            ->get();
        }
        else
        {
            $userId = Auth::user()->id;
            $usercity = UserCity::where('user_id',$userId)->pluck('city_id');

            $staffList = User::whereHas(
                'roles', function($q){
                    $q->whereIn('id', [7]);
                }
            )->whereHas('usercity',function($query) use($usercity){
                $query->whereIn('city_id',$usercity);
            })
            ->with('userDetail')
            ->with([
                'totalOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->whereIn('trip_status_id', [1,2,3,4,5,6,7])->where('force_status',1);
                },
                'deliveredOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',1)->where('force_status',1);
                },
                'cancelOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'returnOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'riderFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate);
                },
                'verifyFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('date', $requestDate);
                }
            ])
            ->get();
        }

        return view('admin.daily-fuel-sheet',compact('staffList','breadcrumbs','requestDate'));
    }

    //weekly fuel sheet
    public function weeklyFuelSheet(Request $request)
    {
        $breadcrumbs = [
            'name' => 'Weekly Fuel Sheet', 
        ];
        
        if($request->date && $request->to)
        {
            $requestDate = $request->date;
            $requestTo = $request->to;
        }
        else
        {
            $requestDate = \Carbon\Carbon::now();
            $requestTo = \Carbon\Carbon::now();
        }

        if(Auth::user()->hasAnyRole('admin'))
        {
            $userId = Auth::user()->id;

            $staffList = User::whereHas(
                'roles', function($q){
                    $q->whereIn('id', [7]);
                }
            )
            ->with('userDetail')
            ->with([
                'totalOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->whereIn('trip_status_id', [1,2,3,4,5,6,7])->where('force_status',1);
                },
                'deliveredOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->where('status',1)->where('force_status',1);
                },
                'cancelOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->where('status',0)->where('force_status',1);
                },
                'returnOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->where('status',0)->where('force_status',1);
                },
                'riderFuelCalculation' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo);
                },
                'verifyFuelCalculation' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('date','>=', $requestDate)->whereDate('date','<=',$requestTo);
                }
            ])
            ->get();
        }
        else
        {
            $userId = Auth::user()->id;
            $usercity = UserCity::where('user_id',$userId)->pluck('city_id');

            $staffList = User::whereHas(
                'roles', function($q){
                    $q->whereIn('id', [7]);
                }
            )->whereHas('usercity',function($query) use($usercity){
                $query->whereIn('city_id',$usercity);
            })
            ->with('userDetail')
            ->with([
                'totalOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->whereIn('trip_status_id', [1,2,3,4,5,6,7])->where('force_status',1);
                },
                'deliveredOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->where('status',1)->where('force_status',1);
                },
                'cancelOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->where('status',0)->where('force_status',1);
                },
                'returnOrders' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo)->where('status',0)->where('force_status',1);
                },
                'riderFuelCalculation' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('created_at','>=', $requestDate)->whereDate('created_at','<=',$requestTo);
                },
                'verifyFuelCalculation' => function($query) use($requestDate, $requestTo){
                    $query->whereDate('date','>=', $requestDate)->whereDate('date','<=',$requestTo);
                }
            ])
            ->get();
        }

        return view('admin.weekly-fuel-sheet',compact('staffList','breadcrumbs'));
    }

    //verified daily sheet
    public function verifyDailySheet(Request $request)
    {
        $rider_id = $request->rider_id;
        $date = $request->date;

        $find_rider = User::where('id', $rider_id)->with('userDetail')
        ->with([
            'riderFuelCalculation' => function($query) use($date){
                $query->whereDate('created_at', $date);
            }
        ])
        ->first();

        $first_fuel = $find_rider->riderFuelCalculation->first()->fuel ?? 0;
        $c_rate = $find_rider->userDetail ? $find_rider->userDetail->commission : 0;
        $other_fuel = $find_rider->riderFuelCalculation->skip(1)->sum('fuel') ?? 0;
        $fuel_rate = $find_rider->riderFuelCalculation->first()->fuel_rate ?? 0;

        $remarks = $find_rider->name .' Data has been verified by '. Auth::user()->name;

        $verified_data = [
            'rider_id' => $rider_id,
            'first_fuel' => $first_fuel,
            'c_rate' => $c_rate,
            'other_fuel' => $other_fuel,
            'fuel_rate' => $fuel_rate,
            'remarks' => $remarks,
            'verified_by' => Auth::user()->id,
            'date' => $date,
        ];

        VerifiedFuelCalculation::create($verified_data);

        return redirect()->back()->with('success',$remarks);
    }

    //verified daily fuel sheet
    public function verifiedDailyFuelSheet(Request $request)
    {
        $breadcrumbs = [
            'name' => 'Verified Daily Fuel Sheet', 
        ];
        
        if($request->date)
        {
            $requestDate = $request->date;
        }
        else
        {
            $requestDate = \Carbon\Carbon::now();
        }

        if(Auth::user()->hasAnyRole('admin'))
        {
            $userId = Auth::user()->id;

            $staffList = User::whereHas(
                'roles', function($q){
                    $q->whereIn('id', [7]);
                }
            )
            ->with('userDetail')
            ->with([
                'totalOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->whereIn('trip_status_id', [1,2,3,4,5,6,7])->where('force_status',1);
                },
                'deliveredOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',1)->where('force_status',1);
                },
                'cancelOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'returnOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'riderFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate);
                },
                'verifyFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('date', $requestDate);
                }
            ])
            ->get();
        }
        else
        {
            $userId = Auth::user()->id;
            $usercity = UserCity::where('user_id',$userId)->pluck('city_id');

            $staffList = User::whereHas(
                'roles', function($q){
                    $q->whereIn('id', [7]);
                }
            )->whereHas('usercity',function($query) use($usercity){
                $query->whereIn('city_id',$usercity);
            })
            ->with('userDetail')
            ->with([
                'totalOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->whereIn('trip_status_id', [1,2,3,4,5,6,7])->where('force_status',1);
                },
                'deliveredOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',1)->where('force_status',1);
                },
                'cancelOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'returnOrders' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate)->where('status',0)->where('force_status',1);
                },
                'riderFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('created_at', $requestDate);
                },
                'verifyFuelCalculation' => function($query) use($requestDate){
                    $query->whereDate('date', $requestDate);
                }
            ])
            ->get();
        }

        return view('admin.verified-daily-fuel-sheet',compact('staffList','breadcrumbs','requestDate'));
    }

    //edit daily sheet
    public function editDailySheet(Request $request)
    {
        $breadcrumbs = [
            'name' => 'Edit Fuel Sheet', 
        ];

        $rider_id = $request->rider_id;
        $date = $request->date;

        $find_rider = User::where('id', $rider_id)->with('userDetail')
        ->with([
            'riderFuelCalculation' => function($query) use($date){
                $query->whereDate('created_at', $date);
            }
        ])
        ->first();

        $first_fuel = $find_rider->riderFuelCalculation->first()->fuel ?? 0;
        $c_rate = $find_rider->userDetail ? $find_rider->userDetail->commission : 0;
        $other_fuel = $find_rider->riderFuelCalculation->skip(1)->sum('fuel') ?? 0;
        $fuel_rate = $find_rider->riderFuelCalculation->first()->fuel_rate ?? 0;

        $remarks = $find_rider->name .' Data has been verified by '. Auth::user()->name;
        $rider_name = $find_rider->name;

        return view('admin.edit-fuel-sheet',compact('rider_id','breadcrumbs','date','first_fuel','c_rate','other_fuel','fuel_rate','remarks','rider_name'));
    }

    //update daily sheet
    public function updateDailySheet(Request $request)
    {
        $verified_data = [
            'rider_id' => $request->rider_id,
            'first_fuel' => $request->first_fuel,
            'c_rate' => $request->c_rate,
            'other_fuel' => $request->other_fuel,
            'fuel_rate' => $request->fuel_rate,
            'remarks' => $request->remarks,
            'verified_by' => Auth::user()->id,
            'date' => $request->date,
        ];

        VerifiedFuelCalculation::create($verified_data);

        return redirect()->route('dailyFuelSheet')->with('success','Data Edited Successfully!');
    }
}
